@@ -3,6 +3,7 @@ from django.template import RequestContext
 
 from django_filters.filterset import FilterSet
 
+
 def object_filter(request, model=None, queryset=None, template_name=None, extra_context=None,
     context_processors=None, filter_class=None):
     if model is None and filter_class is None:
@@ -13,7 +14,7 @@ def object_filter(request, model=None, queryset=None, template_name=None, extra_
         meta = type('Meta', (object,), {'model': model})
         filter_class = type('%sFilterSet' % model._meta.object_name, (FilterSet,),
             {'Meta': meta})
-    filterset = filter_class(request.GET, queryset=queryset)
+    filterset = filter_class(request.GET or None, queryset=queryset)
 
     if not template_name:
         template_name = '%s/%s_filter.html' % (model._meta.app_label, model._meta.object_name.lower())
